@@ -9,8 +9,6 @@ $doubleBuffer = GL_TRUE;
 
 $smooth = GL_TRUE;
 $lighting = GL_TRUE;
-$light0 = GL_TRUE;
-$light1 = GL_TRUE;
 
 $MAXVERTS = 10000;
 
@@ -46,7 +44,7 @@ sub read_surface_bin {
 	my ($filename) = @_;
 	
 	open(F, "<$filename") || die "couldn't read $filename\n";
-	binmode(F);
+	
 	$numverts = 0;
 	while ($numverts < $MAXVERTS and read(F, $_, 12)==12) {
 		@d = map(($_-32000) / 10000 , unpack("nnnnnn", $_));
@@ -103,7 +101,7 @@ sub Draw {
       for ($xrot=0.0;$xrot<=360.0;$xrot+=10.0) {
 	 draw1();
       }
-      MyExit(0);
+      exit(0);
    }
    else {
       draw1();
@@ -187,8 +185,8 @@ sub Reshape {
 sub Key {
 	my ($key, $x, $y ) = @_;
 	
-	if ($key == 27 or $key == ord 'q' or $key == ord 'Q') {
-		MyExit();
+	if ($key == 27) {
+		exit;
 	} elsif ($key == ord('s')) {
 		$smooth = !$smooth;
 		if ($smooth) {
@@ -196,20 +194,6 @@ sub Key {
 		} else {
 		    glShadeModel(GL_FLAT);
 		}
-	} elsif ($key == ord('0')) {
-		$light0 = !$light0;
-		if ($light0) {
-		    glEnable(GL_LIGHT0);
-		} else {
-		    glDisable(GL_LIGHT0);
-		}
-	} elsif ($key == ord('1')) {
-		$light1 = !$light1;
-		if ($light1) {
-		    glEnable(GL_LIGHT1);
-		} else {
-		    glDisable(GL_LIGHT1);
-		}
 	} elsif ($key == ord('l')) {
 		$lighting = !$lighting;
 		if ($lighting) {
@@ -268,7 +252,7 @@ sub SpecialKey {
 #   return GL_TRUE;
 #}
 
-my $WindowId;
+
 
 #int main(int argc, char **argv)
 #{
@@ -281,7 +265,6 @@ my $WindowId;
 #      exit(0);
 #   }
 
-   glutInit();
    glutInitWindowPosition(0, 0);
    glutInitWindowSize(400, 400);
    
@@ -290,22 +273,14 @@ my $WindowId;
    $type |= ($doubleBuffer) ? GLUT_DOUBLE : GLUT_SINGLE;
    glutInitDisplayMode($type);
 
-   if (($WindowId = glutCreateWindow("Isosurface")) <= 0) {
+   if (glutCreateWindow("Isosurface") <= 0) {
       exit(0);
    }
 
 #   /* Make sure server supports the vertex array extension */
-#    $extensions = glGetString( GL_EXTENSIONS );
-#    if ($extensions !~ /\bGL_EXT_vertex_array\b/
-# 	or OpenGL::_have_glp and not OpenGL::_have_glx and 0) { # OS/2 reports wrong
-#       $use_vertex_arrays = GL_FALSE;
-#    }
-#    print "Extensions: '$extensions'.\n";
-   if (defined &OpenGL::glVertexPointerEXT_c) {
-     print "Using Vertex Array...\n";
-   } else {
-     print "No Vertex Array extension found, using a slow method...\n";
-     $use_vertex_arrays = 0;
+   $extensions = glGetString( GL_EXTENSIONS );
+   if ($extensions !~ /\bGL_EXT_vertex_array\b/) {
+      $use_vertex_arrays = GL_FALSE;
    }
 
    Init();
@@ -315,13 +290,3 @@ my $WindowId;
    glutSpecialFunc(\&SpecialKey);
    glutDisplayFunc(\&Draw);
    glutMainLoop();
-
-# This leaves GLUT running (at least under OS/2...).
-
-#sub MyExit {
-#  exit shift if $WindowId <= 0;
-#  glutDestroyWindow($WindowId);
-#  warn "Exiting...\n";
-#}
-
-sub MyExit { exit }		# Segfaults under OS/2...
